@@ -7,11 +7,8 @@ from yaml import safe_dump, safe_load
 from faker.providers import BaseProvider as FakerProvider
 
 from .data_gen_exceptions import DataGenNameError
-from .output_streams import (
-    DebugOutputStream,
-    OutputStream,
-)
-from .parse_factory_yaml import parse_factory
+from .output_streams import DebugOutputStream, OutputStream
+from .parse_recipe_yaml import parse_recipe
 from .data_generator_runtime import output_batches, StoppingCriteria, Globals
 from . import SnowfakeryPlugin
 
@@ -20,7 +17,7 @@ from . import SnowfakeryPlugin
 #
 # 1. Yaml parsing into Python data structures.
 # 2. Walking the tree, sorting things into groups like macros, file inclusions,
-#    etc., and doing the file inclusions (parse_factory_yaml.parse_factory)
+#    etc., and doing the file inclusions (parse_recipe_yaml.parse_recipe)
 # 2 a) merge options informtion from the parse with options from the
 #      environment
 # 3. Generating the objects top to bottom (including evaluating Jinja) in
@@ -35,11 +32,11 @@ class ExecutionSummary:
 
     def __init__(self, parse_results, runtime_results):
         self.tables = parse_results.tables
-        self.dom = parse_results.templates
+        self.templates = parse_results.templates
         self.intertable_dependencies = runtime_results.intertable_dependencies
 
     def summarize_for_debugging(self):
-        return self.intertable_dependencies, self.dom
+        return self.intertable_dependencies, self.templates
 
 
 def merge_options(option_definitions: List, user_options: Mapping) -> Tuple[Dict, set]:
@@ -131,7 +128,7 @@ def generate(
     output_stream = output_stream or DebugOutputStream()
 
     # parse the YAML and any it refers to
-    parse_result = parse_factory(open_yaml_file)
+    parse_result = parse_recipe(open_yaml_file)
 
     # figure out how it relates to CLI-supplied generation variables
     options, extra_options = merge_options(parse_result.options, user_options)
