@@ -1,5 +1,4 @@
 from collections import defaultdict
-from functools import partial
 from datetime import date
 from contextlib import contextmanager
 
@@ -11,7 +10,7 @@ import yaml
 
 from .utils.template_utils import FakerTemplateLibrary
 
-from .template_funcs import template_funcs
+from .template_funcs import StandardFuncs
 from .data_gen_exceptions import DataGenSyntaxError, DataGenNameError
 import snowfakery  # noqa
 
@@ -66,7 +65,7 @@ class FinishedChecker:
         if last_used_id == self.target_progress_id:
             raise RuntimeError(
                 f"{self.stopping_criteria.tablename} max ID was {self.target_progress_id} "
-                f"before evaluating factory and is {last_used_id} after. "
+                f"before evaluating recipe and is {last_used_id} after. "
                 f"At this rate we will never hit our target of {target_id}!"
             )
 
@@ -171,18 +170,35 @@ class Globals(yaml.YAMLObject):
 
 class JinjaTemplateEvaluatorFactory:
     def __init__(self):
-        self.template_compiler = jinja2.Environment(
-            block_start_string="<%",
-            block_end_string="%>",
-            variable_start_string="<<",
-            variable_end_string=">>",
-        )
+        self.compilers = [
+            jinja2.Environment(
+                block_start_string="<%",
+                block_end_string="%>",
+                variable_start_string="<<",
+                variable_end_string=">>",
+            ),
+            jinja2.Environment(
+                block_start_string="${%",
+                block_end_string="%}",
+                variable_start_string="${{",
+                variable_end_string="}}",
+            ),
+        ]
+
+    def compiler_for_string(self, definition: str):
+        for compiler in self.compilers:
+            for delimiter in ["block_start_string", "variable_start_string"]:
+                if getattr(compiler, delimiter) in definition:
+                    return compiler
+        return None
 
     def get_evaluator(self, definition: str):
         assert isinstance(definition, str), definition
-        if "<<" in definition or "<%" in definition:
+        compiler = self.compiler_for_string(definition)
+
+        if compiler:
             try:
-                template = self.template_compiler.from_string(definition)
+                template = compiler.from_string(definition)
                 return lambda context: template.render(context.field_vars())
             except jinja2.exceptions.TemplateSyntaxError as e:
                 raise DataGenSyntaxError(str(e), None, None) from e
@@ -217,6 +233,14 @@ class Interpreter:
         self.faker_template_library = FakerTemplateLibrary(faker_providers)
         self.globals = globals or Globals()
 
+        # inject context into the standard functions
+        standard_funcs_obj = StandardFuncs(self).custom_functions()
+        self.standard_funcs = {
+            name: getattr(standard_funcs_obj, name)
+            for name in dir(standard_funcs_obj)
+            if not name.startswith("_") and name != "context"
+        }
+
 
 class RuntimeContext:
     """Local "stack frame" type object. RuntimeContexts live on the Python stack.
@@ -227,7 +251,7 @@ class RuntimeContext:
     but internally its mostly just proxying to other classes."""
 
     obj: Optional["ObjectRow"] = None
-    template_evaluator_factory = JinjaTemplateEvaluatorFactory()
+    template_evaluator_recipe = JinjaTemplateEvaluatorFactory()
 
     def __init__(
         self,
@@ -288,7 +312,7 @@ class RuntimeContext:
         return self.interpreter.output_stream
 
     def get_evaluator(self, definition: str):
-        return self.template_evaluator_factory.get_evaluator(definition)
+        return self.template_evaluator_recipe.get_evaluator(definition)
 
     @property
     def evaluation_namespace(self):
@@ -318,28 +342,20 @@ class EvaluationNamespace(NamedTuple):
         return {
             "id": obj.id if obj else None,
             "count": obj.id if obj else None,
+            "child_index": obj._child_index if obj else None,
             "this": obj,
             "today": interpreter.globals.today,
             "fake": interpreter.faker_template_library,
-            "fake_i18n": lambda locale: FakerTemplateLibrary(locale),
             **interpreter.options,
             **interpreter.globals.object_names,
             **(obj._values if obj else {}),
             **interpreter.plugin_function_libraries,
         }
 
-    # todo: should be replaced with the plugin architecture
     def field_funcs(self):
         "Injects context into functions from template_funcs module."
 
-        def curry(func):
-            rc = partial(func, self.runtime_context)
-            if hasattr(func, "lazy"):
-                rc.lazy = func.lazy
-            return rc
-
-        funcs = {name: curry(func) for name, func in template_funcs.items()}
-        return {**funcs}
+        return self.runtime_context.interpreter.standard_funcs
 
     def executable_blocks(self):
         "Return mapping of functions that can be used in YAML block functions"
@@ -375,11 +391,12 @@ class ObjectRow(yaml.YAMLObject):
     yaml_dumper = yaml.SafeDumper
     yaml_tag = "!snowfakery_objectrow"
 
-    __slots__ = ["_tablename", "_values"]
+    __slots__ = ["_tablename", "_values", "_child_index"]
 
-    def __init__(self, tablename, values=()):
+    def __init__(self, tablename, values=(), index=0):
         self._tablename = tablename
         self._values = values
+        self._child_index = index
 
     def __getattr__(self, name):
         try:
@@ -407,7 +424,7 @@ class ObjectRow(yaml.YAMLObject):
 
 def output_batches(
     output_stream,
-    factories: List,
+    templates: List,
     options: Dict,
     stopping_criteria: Optional[StoppingCriteria] = None,
     continuation_data: Globals = None,
@@ -416,7 +433,7 @@ def output_batches(
     faker_providers: List[object] = None,
 ) -> Globals:
     """Generate 'count' batches to 'output_stream' """
-    # check the stopping_criteria against the factories available
+    # check the stopping_criteria against the templates available
     if stopping_criteria:
         stop_table_name = stopping_criteria.tablename
         if stop_table_name not in tables:
@@ -448,17 +465,17 @@ def output_batches(
 
     runtimecontext = RuntimeContext(interpreter=interpreter)
     continuing = bool(continuation_data)
-    loop_over_factories(factories, runtimecontext, output_stream, continuing)
+    loop_over_templates(templates, runtimecontext, output_stream, continuing)
     return interpreter.globals
 
 
-def loop_over_factories(factories, runtimecontext, output_stream, continuing):
+def loop_over_templates(templates, runtimecontext, output_stream, continuing):
     finished = False
     while not finished:
-        for factory in factories:
-            should_skip = factory.just_once and continuing is True
+        for template in templates:
+            should_skip = template.just_once and continuing is True
             if not should_skip:
-                factory.generate_rows(output_stream, runtimecontext)
+                template.generate_rows(output_stream, runtimecontext)
         finished = runtimecontext.check_if_finished()
 
         continuing = True
